"""Top-level package for NotificationAPI Python Server SDK."""

__author__ = """Sahand Seifi"""
__email__ = "sahand.seifi@gmail.com"
__version__ = "0.0.4"
